Documentation
¶
Overview ¶
Package reedsshepp implements ReedsSheppPath planning based on [ompl](https://github.com/ompl/ompl) library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Path ¶
type Path struct {
// contains filtered or unexported fields
}
Path corresponds to ReedsSheppPath.
func AvailablePaths ¶
AvailablePaths returns all possible ReedsSheppPaths that can reach the `goal` state from the `start` state, given a `turningRadius`.
func MinLengthPath ¶
MinLengthPath returns the shortest `ReedsSheppPath` among all possible paths from the `start` state to the `goal` state, given a `turningRadius`. In case there are multiple paths with the same length, one of them is randomly selected and returned. The shortest ReedsSheppPath length can be obtained using the `Length` function of the returned `ReedsSheppPath`.
func (*Path) Interpolate ¶
func (p *Path) Interpolate(stepSize float64) []StateWithDirection
Interpolate interpolates ReedsSheppPath by `stepSize`, returning `StateWithDirection` list.
func (*Path) Segments ¶
func (p *Path) Segments() []PathSegment
Segments returns all `PathSegment` information about ReedsSheppPath.
type PathCourseType ¶
type PathCourseType int
PathCourseType represents ReedsSheppPath segment course type: L, S, R.
const ( CourseTypeNone PathCourseType = iota CourseTypeLeft CourseTypeStraight CourseTypeRight )
type PathSegment ¶
type PathSegment struct {
Length float64
CourseType PathCourseType
}
func (PathSegment) Direction ¶
func (s PathSegment) Direction() Direction
Direction returns `Direction` information(forward or backward) about the segment.
type StateWithDirection ¶
StateWithDirection represents `State` information with `Direction` information